#
# spec file for package lightspark
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if %packman_bs
%bcond_without ffmpeg
%bcond_without rtmp
%else
%bcond_with ffmpeg
%bcond_with rtmp
%endif

Name:           lightspark
Version:        0.7.2.99+git20140327.1809
Release:        8.3
Summary:        Modern, free, open-source flash player implementation
License:        LGPL-3.0+
Group:          Productivity/Multimedia/Other
Url:            https://launchpad.net/lightspark/
Source0:        lightspark.tar.xz
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  hicolor-icon-theme
BuildRequires:  libjpeg-devel
BuildRequires:  llvm-devel >= 2.8
BuildRequires:  nasm
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glibmm-2.4)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libxml++-2.6) >= 2.33.1
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
%if %{with rtmp}
BuildRequires:  pkgconfig(librtmp)
%endif
%if %{with ffmpeg}
#BuildRequires:  pkgconfig(libavcodec)
#BuildRequires:  pkgconfig(libavformat)
#BuildRequires:  pkgconfig(libavutil)
BuildRequires:  libffmpeg-devel
%endif
Recommends:     %{_bindir}/gnash

%description
Lightspark is a modern, free, open-source flash player implementation.

%package plugin
Summary:        NPAPI plugin for lightspark
Group:          Productivity/Multimedia/Other
Requires:       %{name} = %{version}
Enhances:       browser(npapi)
Conflicts:      flash-player
Conflicts:      gnash-browser-plugin

%description plugin
NPAPI plugin for lightspark.

%prep
%setup -q -n %{name}

%build
export CFLAGS='%{optflags}'
export CXXFLAGS='%{optflags}'
mkdir build
cd build
cmake -DCMAKE_BUILD_WITH_INSTALL_RPATH=1 \
      -DAUDIO_BACKEND=sdl \
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DLIB_SUFFIX=$(echo %{_lib} | cut -b4-) \
      -DCMAKE_BUILD_TYPE=RelWithDebugInfo \
      -DPLUGIN_DIRECTORY=%{_libdir}/browser-plugins \
      -DENABLE_LIBAVCODEC=%{?with_ffmpeg:YES}%{!?with_ffmpeg:NO} \
      -DENABLE_RTMP=%{?with_rtmp:YES}%{!?with_rtmp:NO} ..
make %{?jobs:-j%jobs}

%install
cd build
%make_install
cd ..
%find_lang %{name}
rm -f %{buildroot}%{_libdir}/%{name}/lib%{name}.so
# Not in hicolor theme (lp#1000840)
rm -rf %{buildroot}%{_datadir}/icons/hicolor/20x20

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files -f %{name}.lang
%defattr(0644,root,root,0755)
%doc COPYING.LESSER ChangeLog
%config(noreplace) %{_sysconfdir}/xdg/lightspark.conf
%attr(0755,root,root) %{_bindir}/lightspark
%attr(0755,root,root) %{_bindir}/tightspark
%{_datadir}/lightspark
%{_datadir}/applications/lightspark.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_mandir}/man1/lightspark.1*
%{_libdir}/lightspark

%files plugin
%defattr(0644,root,root,0755)
%{_libdir}/browser-plugins/liblightsparkplugin.so

%changelog
* Wed Apr 23 2014 johannesobermayr@gmx.de
- Update to latest git version
- Change pulseaudio -> sdl
* Thu May 30 2013 mhrusecky@suse.cz
- fixed build with new llvm: llvm-3.3.patch
* Mon May  6 2013 reddwarf@opensuse.org
- Update to 0.7.2
  * Improved image support: alpha in palettes, abbreviated JPEGs
  * Improved embedded font parsing and text positioning
  * Open links in a browser (plugin only)
  * BitmapData improvements
  * Fixed many crashes
- Remove lightspark-0.7.0-no_glu.patch. Applied upstream.
* Thu Dec 27 2012 reddwarf@opensuse.org
- Update to 0.7.1
  * Fixes for YouTube
  * Support keyboard press and release events
  * Support mouse wheel events and other mouse event improvements
  * Support LLVM 3.2
  * Implemented hit testing of DisplayObjects
  * Parse JPEG images embedded in DefineBits tags
  * Parse RGB15 and paletted images in DefineBitsLossless tags
  * Improved XML support
- Remove lightspark-0.7.0-llvm32.patch, applied upstream.
* Fri Nov 30 2012 reddwarf@opensuse.org
- Add lightspark-0.7.0-llvm32.patch to fix build with LLVM 3.2
* Wed Oct 31 2012 reddwarf@opensuse.org
- Update to 0.7.0
  * Support LZMA compressed SWFs [Requires liblzma]
  * Improved BitmapData support
  * Improved ActionScript compatibility
  * Improved virtual machine performance and memory consumption
  * Improved XML support
  * Experimental support for bytecode optimization at runtime
  * Improved ExternalInterface (browser integration) support
  * Improved performance of JPEG loading
  * Support for XMLSocket
  * Completely redesigned and improved masking support
- Take minimum version of pkgconfig(libxml++-2.6) and llvm-devel
  from CMakeLists.txt and specify them in the BuildRequires
- Add pkgconfig(liblzma), pkgconfig(gl) and pkgconfig(zlib) BuildRequires
- Remove pkgconfig(gobject-2.0) BuildRequire
- Add lightspark-0.7.0-no_glu.patch and remove explicit glu dependency
* Fri Sep 21 2012 idonmez@suse.com
- Add explicit glu dependency
* Fri Jun 22 2012 reddwarf@opensuse.org
- Update to 0.6.0.1
  * Enable RTMP support by default, requires librtmp
  * Fixed support for IEventDispatcher implementation pattern
  * Improved serialization robustness
  * Improved matrix handling
  * Implement string and namespace pooling to reduce memory consumption
  * Proper support for private namespaces
  * Improved support for fonts
  * Support LLVM 3.1
  * Fix full volume issue when PulseAudio flat volumes are enabled
  * Initial support for AIR desktop applications
  * Support for www.bbc.co.uk video player
- Remove lightspark-0.5.7-llvm_31.patch and
  lightspark-0.5.7-ffmpeg_011.patch, applied upstream
- Optionally support RTMP
* Wed Jun  6 2012 reddwarf@opensuse.org
- Fix ffmpeg 0.11 patch, now upstreamed
* Mon May 28 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11
* Thu May 17 2012 reddwarf@opensuse.org
- Update to 0.5.7
* Tue Mar 27 2012 reddwarf@opensuse.org
- Don't remove rpath
* Thu Mar 22 2012 reddwarf@opensuse.org
- Update to 0.5.5
* Sat Dec 11 2010 reddwarf@opensuse.org
- Initial package
